@@ -20,9 +20,10 @@ from .utils import (
     Singleton,
     convert_dicts,
     timing,
+    wrap_backticks,
 )
 
-__version__ = "0.0.10"
+__version__ = "0.0.12"
 
 __all__ = [
     "QsParsingError",
@@ -39,6 +40,7 @@ __all__ = [
     "convert_dicts",
     "escape_string",
     "timing",
+    "wrap_backticks",
 ]
 
 dictConfig({
