@@ -7,6 +7,7 @@ from tortoise.queryset import Q
 from tortoise.query_utils import QueryModifier
 
 from ..const.error import QsParsingError, WrongParamsError
+from .converter import wrap_backticks
 
 logger = getLogger(__name__)
 # To ensure the functionality of the RawSQL
@@ -114,6 +115,7 @@ class SQLizer:
         table: str,
         fields: List[str],
         wheres: Union[str, Q, Dict[str, Any], List[Q]],
+        *,
         index: Optional[str] = None,
         groups: Optional[List[str]] = None,
         having: Optional[str] = None,
@@ -141,7 +143,7 @@ class SQLizer:
     WHERE {}
 {}""".format(
         ", ".join(fields),
-        table,
+        wrap_backticks(table),
         f" FORCE INDEX (`{index}`)" if index else "",
         cls.resolve_wheres(wheres, model),
         "\n".join(i for i in extras if i),
@@ -155,6 +157,7 @@ class SQLizer:
         table: str,
         json_field: str,
         wheres: Union[str, Q, Dict[str, Any], List[Q]],
+        *,
         merge_dict: Optional[Dict[str, Any]] = None,
         path_value_dict: Optional[Dict[str, Any]] = None,
         remove_paths: Optional[List[str]] = None,
@@ -182,7 +185,7 @@ class SQLizer:
             json_obj = f"JSON_MERGE_PATCH({json_obj}, {cls.sqlize_value(merge_dict)})"
 
         sql = f"""
-    UPDATE {table} SET {json_field} =
+    UPDATE {wrap_backticks(table)} SET {json_field} =
     {json_obj}
     WHERE {cls.resolve_wheres(wheres, model)}
 """
@@ -195,6 +198,7 @@ class SQLizer:
         table: str,
         dicts: List[Dict[str, Any]],
         insert_fields: List[str],
+        *,
         upsert_fields: Optional[List[str]] = None,
         merge_fields: Optional[List[str]] = None,
         using_values: bool = False,
@@ -215,14 +219,14 @@ class SQLizer:
             if using_values:
                 upserts = [f"{field}=VALUES({field})" for field in upsert_fields]
                 for mf in merge_fields:
-                    dict_obj = f"COALESCE({table}.{mf}, '{{}}')"
+                    dict_obj = f"COALESCE({wrap_backticks(table)}.{mf}, '{{}}')"
                     upserts.append(f"{mf}=JSON_MERGE_PATCH({dict_obj}, VALUES({mf}))")
                 on_duplicate = f"ON DUPLICATE KEY UPDATE {', '.join(upserts)}"
             else:
                 new_table = f"`new_{table}`"
                 upserts = [f"{field}={new_table}.{field}" for field in upsert_fields]
                 for mf in merge_fields:
-                    dict_obj = f"COALESCE({table}.{mf}, '{{}}')"
+                    dict_obj = f"COALESCE({wrap_backticks(table)}.{mf}, '{{}}')"
                     upserts.append(f"{mf}=JSON_MERGE_PATCH({dict_obj}, {new_table}.{mf})")
                 on_duplicate = f"AS {new_table} ON DUPLICATE KEY UPDATE {', '.join(upserts)}"
 
@@ -232,7 +236,7 @@ class SQLizer:
     VALUES
 {}{}
 """.format(
-        table,
+        wrap_backticks(table),
         ", ".join(insert_fields),
         ",\n".join(values),
         f"\n    {on_duplicate}" if on_duplicate else "",
@@ -245,8 +249,9 @@ class SQLizer:
         cls,
         table: str,
         wheres: Union[str, Q, Dict[str, Any], List[Q]],
-        remain_fields: List[str],
-        assign_field_dict: Dict[str, Any],
+        *,
+        remain_fields: List[str] = None,
+        assign_field_dict: Dict[str, Any] = None,
         to_table: Optional[str] = None,
         model: Optional[Model] = None,
     ) -> Optional[str]:
@@ -255,6 +260,8 @@ class SQLizer:
         if not any([remain_fields, assign_field_dict]):
             raise WrongParamsError("At least one no empty parameter is required between `remain_fields` and `assign_field_dict`")
 
+        remain_fields = remain_fields or []
+        assign_field_dict = assign_field_dict or {}
         fields = [*remain_fields]
         assign_fields = []
         for k, v in assign_field_dict.items():
@@ -262,10 +269,10 @@ class SQLizer:
             assign_fields.append(f"{cls.sqlize_value(v)} {k}")
 
         sql = f"""
-    INSERT INTO {to_table or table}
+    INSERT INTO {wrap_backticks(to_table or table)}
       ({", ".join(fields)})
     SELECT {", ".join(remain_fields + assign_fields)}
-    FROM {table}
+    FROM {wrap_backticks(table)}
     WHERE {cls.resolve_wheres(wheres, model)}
 """
         logger.debug(sql)
@@ -312,21 +319,22 @@ class SQLizer:
         dicts: List[Dict[str, Any]],
         join_fields: List[str],
         update_fields: List[str],
+        *,
         merge_fields: Optional[List[str]] = None,
         using_values: bool = True,
     ) -> Optional[str]:
         if not all([table, dicts, join_fields, update_fields]):
             raise WrongParamsError("Parameters `table`, `dicts`, `join_fields`, `update_fields` are required")
 
-        joins = [f"{table}.{jf}=tmp.{jf}" for jf in join_fields]
-        updates = [f"{table}.{uf}=tmp.{uf}" for uf in update_fields]
+        joins = [f"{wrap_backticks(table)}.{jf}=tmp.{jf}" for jf in join_fields]
+        updates = [f"{wrap_backticks(table)}.{uf}=tmp.{uf}" for uf in update_fields]
         merge_fields = merge_fields or []
         for mf in merge_fields:
-            dict_obj = f"COALESCE({table}.{mf}, '{{}}')"
-            updates.append(f"{table}.{mf}=JSON_MERGE_PATCH({dict_obj}, tmp.{mf})")
+            dict_obj = f"COALESCE({wrap_backticks(table)}.{mf}, '{{}}')"
+            updates.append(f"{wrap_backticks(table)}.{mf}=JSON_MERGE_PATCH({dict_obj}, tmp.{mf})")
 
         sql = f"""
-    UPDATE {table}
+    UPDATE {wrap_backticks(table)}
     JOIN ({SQLizer.build_fly_table(dicts, join_fields + update_fields + merge_fields, using_values, log_sql=False)}
     ) tmp ON {", ".join(joins)}
     SET {", ".join(updates)}
